@@ -2,13 +2,12 @@ package Data::Unixish::date;
 
 use 5.010;
 use strict;
-use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
 use Log::Any '$log';
 use POSIX qw(strftime);
 use Scalar::Util qw(looks_like_number blessed);
 
-our $VERSION = '1.21.1'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 our %SPEC;
 
@@ -70,7 +69,7 @@ Data::Unixish::date - Format date
 
 =head1 VERSION
 
-version 1.21.1
+version 1.20
 
 =head1 DESCRIPTION
 
