@@ -2,11 +2,10 @@ package Data::Unixish::head;
 
 use 5.010;
 use strict;
-use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '1.21.1'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 our %SPEC;
 
@@ -50,7 +49,7 @@ Data::Unixish::head - Output the first items of data
 
 =head1 VERSION
 
-version 1.21.1
+version 1.20
 
 =head1 DESCRIPTION
 
