@@ -2,11 +2,10 @@ package Data::Unixish::sort;
 
 use 5.010;
 use strict;
-use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '1.21.1'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 our %SPEC;
 
@@ -43,7 +42,7 @@ _
             cmdline_aliases => { R=>{} },
         },
     },
-    tags => [qw/ordering/],
+    tags => [qw/sorting/],
 };
 sub sort {
     my %args = @_;
@@ -101,7 +100,7 @@ Data::Unixish::sort - Sort items
 
 =head1 VERSION
 
-version 1.21.1
+version 1.20
 
 =head1 DESCRIPTION
 
